@@ -203,15 +203,17 @@ class CredentialManager(object):
             if secret:
                 prompted = True
 
-        if not secret:
-            # nothing
-            return
+        if secret:
+            cred['secret'] = secret
 
-        cred['secret'] = secret
         if 'type' not in cred and kwargs.get('type'):
             # enhance legacy credentials
             cred['type'] = kwargs.get('type')
 
+        if not cred:
+            # if there is absolutely nothing to report, report None
+            return
+
         # report whether there were any edits to the credential record
         # (incl. being entirely new), such that consumers can decide
         # to save a credentials, once battle-tested
@@ -510,17 +512,17 @@ class CredentialManager(object):
         if not ui.is_interactive:
             lgr.debug('Cannot ask for credential property %r in non-interactive session', name)
             return
-        self._prompt(prompt)
-        return ui.question(name, title=None)
+
+        return ui.question(name, title=prompt)
 
     def _ask_secret(self, type_hint=None, prompt=None):
         if not ui.is_interactive:
             lgr.debug('Cannot ask for credential secret in non-interactive session')
             return
-        self._prompt(prompt)
+
         return ui.question(
             type_hint or 'secret',
-            title=None,
+            title=prompt,
             repeat=self._cfg.obtain(
                 'datalad.credentials.repeat-secret-entry'),
             hidden=self._cfg.obtain(
